Tiro Devanagari Hindi has its origins in a typeface designed for the Murty Classical Library of India book series, so is especially suited to traditional literary publishing but also made with the needs of today’s multiple print and screen media in mind. The Tiro Devanagari design applies a contemporary approach to the traditional styling of 19th and 20th Century metal types exemplified in those of the renowned Nirnaya Sagar Press, and is characterised by broader proportions, more generous counters, and strong diagonal strokes and terminals. The Hindi font balances traditional and modern forms of conjuncts. For the Open Font License release, Tiro Devanagari Hindi has been extended to support additional characters, and features a new italic companion. Each font also includes a Latin subset including diacritics for transcription of Indian languages.

Tiro Devanagari Hindi was designed by John Hudson and Fiona Ross. The italic was adapted by Paul Hanslow.

To contribute, see github.com/TiroTypeworks/Indigo.

### Modern Tiro Indic collection for classical South Asian texts

#### The beauty and challenges of bridging the old and the new

Two type designers separated by an eight-hour time difference, an ocean, and pandemic travel bans collaborated over video calls and email to make a cohesive set of fonts in 8 South Asian languages. In 2012, Harvard University Press commissioned Fiona Ross and John Hudson, through Tiro Typeworks, to design typefaces for the Murty Classical Library of India book series. The publisher needed to reprint ancient Indian literary, historical, and religious texts, including Vedic and early Sanskrit works. Since these old texts had been printed using traditional letterforms and early Indian typography techniques, the new fonts needed to retain some of the traditional style of the old texts, yet be clear and legible in modern print and digital media.

In 2019 Google Fonts approached Tiro to make an extended and updated version of the Murty Fonts to be released as open source fonts in the Tiro Indic collection, offering users traditional text styles suitable for a variety of uses.

#### Study the classics and language structure

Before designing the typefaces, it was important to research classical texts and understand the unique characteristics of the languages.

“We looked at very lovely manuscripts or early Indian printed materials from the 18th or 19th Centuries,” said John Hudson.

To learn more, read Modern Tiro Indic collection for classical South Asian texts.